@@ -22,6 +22,7 @@ use crate::num::INum;
 use crate::num::Num;
 use crate::num::NumIdentity;
 use crate::num::NumTuple;
+use crate::num::NumberExtensions;
 use crate::num::ToRounded;
 
 use crate::geom::Point;
@@ -142,6 +143,19 @@ impl<N: Num> Size<N> {
     pub fn hypot_sqrd(self) -> N {
         (self.width() * self.width()) + (self.height() * self.height())
     }
+
+    pub fn interpolate_to(self, other: Size<N>, n: N) -> Size<N> {
+        let start_f32 = self.to_f32();
+        let other_f32 = other.to_f32();
+        let n_f32: f32 = n.to_rounded();
+
+        let new_size_f32 = (start_f32 * n_f32.inverse()) + (other_f32 * n_f32);
+        new_size_f32.from_f32()
+    }
+
+    pub(crate) fn to_f32(self) -> Size<f32> {
+        self.to_rounded()
+    }
 }
 
 impl<N: Num + Signed> Size<N> {
